# -*- coding: utf-8 -*-
import folium
import json
import pandas

carte = folium.Map(location=[45.243109, 3.883620], zoom_start = 8)

with open('donnees/dep-aura.geojson', encoding='utf-8') as fichier:
    geo_dep = json.load(fichier)
print(geo_dep)

for dep in geo_dep["features"]:
    prop = dep["properties"]
    coord = (prop["pos_x"],prop["pos_y"])
    folium.Marker(coord, 
                  popup = prop["nom"]+" ("+ prop["code"] +")").add_to(carte)

df = pandas.DataFrame({
    "Departement" : [arr["properties"]["code"] for arr in geo_dep["features"]], 
    "Population" : [arr["properties"]["population"] for arr in geo_dep["features"]]
})

folium.Choropleth(geo_data = geo_dep, key_on = "feature.properties.code",
                 data = df, columns = ["Departement", "Population"],
                 threshold_scale = [0, 500000, 1000000, 1500000, 2000000],
                 legend_name = "Population 2018",
                 fill_color = "PuRd").add_to(carte)

carte.save('CartePopulationAura.html')

