#-------------------------------------------
# Serveur web
#-------------------------------------------
from machine import ADC    # module pour la lecture analogique
from machine import Pin
import usocket as socket   # module pour le dialogue sur le reseau

def Eteindretout():
  Eteindreled(ledR)
  Eteindreled(ledB)

def Eteindreled(pinled):
  pinled.value(0)

def Allumerled(pinled):  
  pinled.value(1)

def ConversionTensionTemperature(val_num_A0):
  tension = (2.81*val_num_A0)/1023   # 2.81V et non 3.3V sur AO
  temperature = tension/0.01         # 10mV tous les 10 degr茅s
  return temperature

#-------------------------------------------------------------------
# Fonction premettant de construire le code HTML de la page WEB
#-------------------------------------------------------------------
def web_page(temp):
 
  alerte_en_cours="Aucune"
  if ledR.value() == 1:
    alerte_en_cours="Canicule"
  if ledB.value() == 1:
    alerte_en_cours="Gel"
  
  html = """
  <html>
  <head>
  <title>Station Météo connectée</title>
  <meta charset="UTF-8">  <meta name="viewport" content="width=device-width, initial-scale=1">
  <style>html{font-family: Helvetica; display:inline-block; margin: 0px auto; text-align: center;}
  h1{color: #0F3376; padding: 2vh;}
  .button{display: inline-block; background-color: #4286f4; border: none; 
  border-radius: 4px; color: white; padding: 16px 40px; font-size: 30px; margin: 2px;}</style>
  </head>
  <body>
  <h1>Station Météo connectée</h1>
  <img src="http://www.jcbmathsandco.fr/meteo.svg"/>
  <p>La température est de : <b>""" + str(round(temp,1)) + """ °C</b></p>
  <a href="/?refreshtemp">Demander une réactualisation de la température</a>
  <p>Alerte en cours : <b>"""+ alerte_en_cours +"""</b></p>
  <p>---------</p>
  <p>Vous pouvez déclencher une alerte :</p>
  <p>
  <a href="/?alerte=aucune"><button class="button">Aucune</button></a>
  <a href="/?alerte=canicule"><button class="button">Canicule</button></a>
  <a href="/?alerte=gel"><button class="button">Gel</button></a>
  </p>
  </body>
  </html>"""
  return html
  
#-------------------------------------------
# Programme principal
#-------------------------------------------
adc0=ADC(0)                # initialisation pour la lecture sur A0

#-----------------------------------------
# on d茅clare les broches pour la led RGB
#-----------------------------------------
ledB=Pin(5,Pin.OUT)  #D1
ledR=Pin(0,Pin.OUT)  #D3

Eteindretout()

s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)  # on ouvre un connecteur reseau de dialogue
s.bind(('', 80)) # on lie ce connecteur sur notre r茅seau sur le port 80
s.listen(5) # on se met en position d'茅coute pour capter des demandes de dialogue

while True:
    # on va lire la temp茅rature sur notre LM35
  lect_surAO = adc0.read()  # lecture d'une valeur enti猫re entre 0-1023  
  temp = ConversionTensionTemperature(lect_surAO)
  print("temp茅rature =",str(temp),"掳C") 
  conn, addr = s.accept()   # association du connceteur res茅au avec une demande cliente
  print('Une connexion est r茅alis茅e depuis %s' % str(addr))
  request = conn.recv(1024)  # on recoit les donn茅es
  request = str(request)
  print('Contenu = %s' % request)
  alerte_aucune = request.find('/?alerte=aucune')   # on cherche dans le contenu les mots cl茅s
  alerte_gel = request.find('/?alerte=gel')
  alerte_canicule = request.find('/?alerte=canicule')
  refreshtemp = request.find('/?refreshtemp')
  if alerte_aucune == 6:     # le d茅but de la chaine recherch茅e doit correspondre 脿 la position 6
    print('Aucune alerte')
    Eteindretout()
  if alerte_gel == 6:
    print('Alerte au gel')
    Eteindretout()
    Allumerled(ledB)
  if alerte_canicule == 6:
    print('Alerte 脿 la canicule')
    Eteindretout()
    Allumerled(ledR)
  if refreshtemp == 6:
    lect_surAO = adc0.read()  # lecture d'une valeur enti猫re entre 0-1023  
    temp = ConversionTensionTemperature(lect_surAO)
  response = web_page(temp)
  conn.send(response)  # on envoie la page web au client
  conn.close()
  
  
  
  
  
